@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
 import pkg_resources
 
-__title__ = 'trailblazer'
+__title__ = "trailblazer"
 __version__ = pkg_resources.get_distribution(__title__).version
