@@ -6,6 +6,10 @@ class TrailblazerError(Exception):
         return f"TrailblazerError: {self.message}"
 
 
+class MissingAnalysis(TrailblazerError):
+    """Error for missing analysis"""
+
+
 class MissingFileError(TrailblazerError):
     pass
 
@@ -22,6 +26,10 @@ class TowerError(Exception):
         return f"TowerError: {self.message}"
 
 
+class MissingSqueueOutput(TrailblazerError):
+    """Raised when squeue results sre missing."""
+
+
 class TowerRequirementsError(TowerError):
     """Raised when Tower requirements are not satisfied."""
 
